#!/bin/sh
####################################################################
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
# 5698-WSH
# (C) Copyright IBM Corp. 1998, 2006 All Rights Reserved.
###################################################################


#------------ exit value  ------------
#  0
#  1	Error executing command
#  2    Unable to copy the maestro.tar.Z in the INSTALL_DIR
#  3    Unable to uncompress the maestro.tar.Z
#  4    Unable to untar the maestro.tar.Z



#on stdout warning messages
#on stderr YUO can find system/catalog error messages

#------- get the parametres from the caller -------
MAIN_DIR="$1"
INSTALL_DIR="$2"
MAEUSER="$3"
MASTER="$4"
THISCPU="$5"
COMPANY="$6"
NM_PORT="$7"
VERBOSE="$8"


OS=`uname -s`;export OS
case $OS in
   IRIX64)
     INST_INTERP="IRIX64"; export INST_INTERP
   ;;
   OSF1)
     INST_INTERP="OSF1";   export INST_INTERP
   ;;
   DYNIX/ptx)
     INST_INTERP="DYNIX"; export INST_INTERP
   ;;
   Linux)
     INST_INTERP="Linux";  export INST_INTERP
   ;;
   *)
     INST_INTERP="LINUX_I386"; export INST_INTERP
   ;;
   SunOS)
     case `uname -m` in
     *86*)
         INST_INTERP="SOLARIS_I386"; export INST_INTERP
     ;;
     *)
     ;;                                       
     esac
   ;;
esac

if [ "$VERBOSE" != "-verbose" ]
then
  VERBOSE=""
fi



#
# execute_command is used to execute a command and capture errors.
#
# Arguments:
#	<command> args
execute_command()
{
 $@
 exitValue=$?
 if [ $exitValue -ne 0 ]
 then
   if [ "$VERBOSE" != "-verbose" ]
   then
     echo "The following command failed: $@." >&2
   else
     echo "$@." >&2
   fi
   exit $exitValue
 fi
}


createdir()
{
  arg1=$1
  arg2=$2
  if [ ! -d $arg1 ]
  then
    execute_command mkdir $arg1
    execute_command chown $MAEUSER $arg1
    execute_command chgrp $MAEGROUP $arg1
  fi
  execute_command chmod $arg2 $arg1
}


#
# installconf installs configuration files.  It will not overwrite a
# file that is already there.  It performs some edits on the files to
# set up the current cpu name, master cpu name, company name, the
# user name and the install_dir in the files as appropriate.
#
# Parms:
#	1 - Source file.
#	2 - Destination file.
#	3 - This cpu name (Blank if not needed).
#	4 - Master cpu name (Blank if not needed).
#	5 - Company name (Blank if not needed).
#	6 - Netman port (Blank if not needed). - Defect 122148
installconf()
{
  arg1=$1
  arg2=$2
  arg3=$3
  arg4=$4
  arg5=$5
  arg6=$6

  if [ ! -f $INSTALL_DIR/$arg1 ]
   then
      #echo "`$MECHO $MAE_CUSTOMIZE_SET $ERR_NO_FILE $INSTALL_DIR/$arg1`"   #vedere messaggio
      echo " the following file does not exist "$INSTALL_DIR/$arg1" "
      return
  fi

  if [ ! -f $INSTALL_DIR/$arg2 ]
  then
    cp $INSTALL_DIR/$arg1 $INSTALL_DIR/$arg2
  else
    return
  fi

  if [ -n "$arg3" ]
  then
    sed -e "/=.(this_cpu)/ s/\=.*/\=$arg3/" $INSTALL_DIR/$arg2 >/tmp/o$$ # DEFECT 118914 (cf)
  else
    cp $INSTALL_DIR/$arg2 /tmp/o$$
  fi

  if [ -n "$arg4" ]
  then
    sed -e "/=.(master_cpu)/ s/\=.*/\=$arg4/" /tmp/o$$ >/tmp/o$$~ # DEFECT 118914 (cf)
    rm /tmp/o$$
    mv /tmp/o$$~ /tmp/o$$
  fi

  if [ -n "$arg6" ]
  then
 # sed -e "s'.(tcp_port)'31111'g" /tmp/o$$ >/tmp/o$$~ Defect 122148
    sed -e "s'.(tcp_port)'$arg6'g" /tmp/o$$ >/tmp/o$$~ # Defect 122148
    rm /tmp/o$$
    mv /tmp/o$$~ /tmp/o$$
  fi

  sed -e "s'.(tws_user)'$MAEUSER'g" /tmp/o$$ >/tmp/o$$~
  rm /tmp/o$$
  sed -e "s', *.(user_name)''g" /tmp/o$$~ >/tmp/o$$
  rm /tmp/o$$~


  sed -e "s'.(install_dir)'$INSTALL_DIR'g" /tmp/o$$ >/tmp/o$$~
  rm /tmp/o$$

  sed -e "s'.(tmf_admin)'$TMFADMIN'g" /tmp/o$$~ >/tmp/o$$  # Defect 158647
  rm /tmp/o$$~

  if [ -f $INSTALL_DIR/$arg2 ]
  then
    rm -f $INSTALL_DIR/$arg2.old
  fi

  mv $INSTALL_DIR/$arg2 $INSTALL_DIR/$arg2.old

  if [ -n "$arg5" ]
  then
    sed -e "/company/ s/\=.*/\=\"$arg5\"/" /tmp/o$$ >$INSTALL_DIR/$arg2
  else
    cp /tmp/o$$ $INSTALL_DIR/$arg2
  fi

  rm /tmp/o$$

  execute_command chown $MAEUSER $INSTALL_DIR/$arg2
  execute_command chgrp $MAEGROUP $INSTALL_DIR/$arg2

  if head -1 $INSTALL_DIR/$arg2 | grep "^#!" >/dev/null
  then
    execute_command chmod 0555 $INSTALL_DIR/$arg2
  else
    execute_command chmod 600 $INSTALL_DIR/$arg2
  fi
  #echo "`$MECHO $MAE_CUSTOMIZE_SET $MSG_INSTALLED_CONFFILE $arg2`"         #vedere messaggio
  echo "installed the following file "$arg2" "
}


# installreqconf installs configuration files which are required to be
# updated when new versions of the software are installed.  It will
# also set permissions according to the values passed in.
#
# Parms:
#	1 - Source file.
#	2 - Destination file.
#	3 - Permissions.
#	4 - This cpu name (Blank if not needed).
#	5 - Master cpu name (Blank if not needed).
#	6 - Company name (Blank if not needed).
installreqconf()
{
  arg1=$1
  arg2=$2
  arg3=$3
  arg4=$4
  arg5=$5
  arg6=$6
  if [ -f $INSTALL_DIR/$arg2 ]
  then
    #echo "`$MECHO $MAE_CUSTOMIZE_SET $MSG_SAVING_CONFFILE $INSTALL_DIR/$arg2 $INSTALL_DIR/config.old/$arg2`" #vedere messaggio
    echo "saving as "$INSTALL_DIR/$arg2" "$INSTALL_DIR/config.old/$arg2" "
    execute_command rm -f $INSTALL_DIR/config.old/$arg2
    execute_command mv $INSTALL_DIR/$arg2 $INSTALL_DIR/config.old/$arg2
  fi

  src="$INSTALL_DIR/$arg1"
  dest="$INSTALL_DIR/$arg2"
  perm=$arg3

  installconf $arg1 $arg2 $arg4 $arg5 $arg6

  execute_command chown $MAEUSER $src
  execute_command chgrp $MAEGROUP $src
  execute_command chmod $perm $src

  execute_command chown $MAEUSER $dest
  execute_command chgrp $MAEGROUP $dest
  execute_command chmod $perm $dest
}

#
# setbinmods sets the permissions for files in the bin directory.  In
# addition to the parameters passed in it uses the environment
# variables USERSCRIPTS and BATCHPROGS to affect what permissions are
# set.
#
# Parms:
#	1 - Filename.
setbinmods()
{
  arg1=$1
  execute_command chown $MAEUSER $arg1
  execute_command chgrp $MAEGROUP $arg1
  if echo $USERSCRIPTS|awk '{ for (i=1;i<=NF;i++) print $i; }'|grep "$arg1" > /dev/null
  then
    execute_command chmod 0555 $arg1
  elif head -1 $arg1|grep "^#!" > /dev/null
  then
    execute_command chmod 500 $arg1
  else
    execute_command chmod 6511 $arg1
  fi
}

#
# setdemomods set permissions for files in the demo group.
#
# Parms:
#	1 - Filename.
setdemomods()
{
  expr $1 : '.*\.old' >/dev/null && return
  arg1=$1
  execute_command chown $MAEUSER $arg1
  execute_command chgrp $MAEGROUP $arg1
  rm -f $arg1.old
  execute_command mv $arg1 $arg1.old
  sed -e "s!.(install_dir)!$INSTALL_DIR!g" $arg1.old | sed -e "s!.(tws_user)!$MAEUSER!g" >$arg1
  execute_command chown $MAEUSER $arg1
  execute_command chgrp $MAEGROUP $arg1

  if head -1 $arg1|grep "^#!" >/dev/null
  then
    execute_command chmod 755 $arg1
  else
    execute_command chmod 644 $arg1
  fi
}

#
#
# Start of Main Script Logic.
#

CMD_GROUPS=/usr/bin/groups
if [ ! -x /usr/bin/groups ]
then
	if [ -x /usr/ucb/groups ]
	then
		CMD_GROUPS=/usr/ucb/groups
	fi
fi


echo "twsTier2ActionInProgress...."
echo "MAIN_DIR=$MAIN_DIR"
echo "INSTALL_DIR=$INSTALL_DIR"
echo "MAEUSER=$MAEUSER"

#
#At present we are not aware of any standard way of finding out primary
#group of a user. If we can, following case statement should be replaced.
#
case $OS in
   OSF1|IRIX64|DYNIX/ptx)
            MAEGROUP=`id -gn $MAEUSER`
          ;;

   Linux)
              MAEGROUP=`$CMD_GROUPS $MAEUSER | awk -F: '{print $2}' | cut -d" " -f2`
          ;;

          *)
              MAEGROUP=`$CMD_GROUPS $MAEUSER | cut -d" " -f 1-1`
          ;;
esac

export MAEGROUP

echo MAEGROUP=$MAEGROUP

cd "$INSTALL_DIR"
#assumo che la MAIN_DIR sia quella del CD.

if [ "$OS" = "Linux" ]
then
  cp $MAIN_DIR/maestro.tar.gz $INSTALL_DIR/maestro.tar.gz
  ACTION_TOOL_RET_COD=$?
else
  cp $MAIN_DIR/maestro.tar.Z $INSTALL_DIR/maestro.tar.Z
  ACTION_TOOL_RET_COD=$?
fi
if [ $ACTION_TOOL_RET_COD -ne 0 ]
then
 rm -f ${tar_file}.gz
 exit 2
fi

tar_file=maestro.tar

if [ "$OS" = "Linux" ]
then
 if [ -s ${tar_file}.gz ]
 then

   echo "Uncompressing ${tar_file} and extracting Maestro files..."

   (gzip -d -c < ${tar_file}.gz ; echo $? > /tmp/err$$) | tar -xovf -
   tar_ret=$?

   uncompress_ret=`cat /tmp/err$$`
   rm -f /tmp/err$$

   if [ $uncompress_ret -ne 0 ]
   then
      echo "Failed to uncompress ${tar_file}.gz."
      echo "Please correct the problem and run twsinst again."
      rm -f ${tar_file}.gz
      exit 3
   fi

   if [ $tar_ret -ne 0 ]
   then
      echo "An error occurred trying to extract maestro files from the $tar_file"
      echo "Please correct the error and run twsinst again."
      rm -f ${tar_file}.gz
       exit 4
   fi
  else
  rm -f ${tar_file}.gz
  exit 2
 fi
else
if [ -s ${tar_file}.Z ]
then

   echo "Uncompressing ${tar_file} and extracting Maestro files..."

   uncompress ${tar_file}.Z

   if [ $? -ne 0 ]
   then
      echo "Failed to uncompress ${tar_file}.Z."
      echo "Please correct the problem and run twsinst again."
      rm -f ${tar_file}.Z
      exit 3
   fi

   tar -xovf ${tar_file}

   if [ $? -ne 0 ]
   then
      echo "An error occurred trying to extract maestro files from the $tar_file"
      echo "Please correct the error and run twsinst again."
      rm -f ${tar_file}.Z
      exit 4
   fi

   rm ${tar_file}

else
rm -f ${tar_file}.Z
exit 2
fi
fi

HOSTNAME=`uname -n`; export HOSTNAME
ACTIONTOOLS_DIR="$INSTALL_DIR/_uninstall/ACTIONTOOLS"; export ACTIONTOOLS_DIR
mkdir -p "$ACTIONTOOLS_DIR"
cp -R "$MAIN_DIR"/ACTIONTOOLS/ "$INSTALL_DIR/_uninstall"
if [ ! -f "$ACTIONTOOLS_DIR/METHOD_TIER2.historyFile" -a ! -f "$ACTIONTOOLS_DIR/FLOW_FRESH.historyFile" ]
then       
    echo "creating the historyFiles for the TIER2"                   
    ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT  
    ACTION_TOOL_RET_STDERR="";export ACTION_TOOL_RET_STDERR  
    ACTION_TOOL_RET_COD=0
    `$ACTIONTOOLS_DIR/echoOnFile.sh "$ACTIONTOOLS_DIR/METHOD_TIER2.historyFile" "$TWS_USER" "$HOSTNAME" 1>/tmp/twsCmdstdOut 2>/tmp/twsCmdstdErr`
    `$ACTIONTOOLS_DIR/echoOnFile.sh "$ACTIONTOOLS_DIR/FLOW_FRESH.historyFile" "$TWS_USER" "$HOSTNAME" 1>/tmp/twsCmdstdOut 2>/tmp/twsCmdstdErr` 
    ACTION_TOOL_RET_COD=$?                                   
    ACTION_TOOL_RET_STDOUT="`cat /tmp/twsCmdstdOut`"         
    ACTION_TOOL_RET_STDERR="`cat /tmp/twsCmdstdErr`"           
fi                                                              

 
execute_command chmod 555 bin/ucomp                                             
execute_command chown $MAEUSER $INSTALL_DIR
execute_command chgrp $MAEGROUP $INSTALL_DIR
execute_command chmod 755 $INSTALL_DIR
createdir mozart 755                                                
createdir config.old 755         
createdir config.old/methods 755 
FILELIST="atjobs audit bin catalog codeset config config.old demo ftbox man mozart network OV pids pobox schedlog stdlist postinstall preinstall setup stdlist/traces tmp unsupported version zoneinfo"

execute_command chown $MAEUSER  $FILELIST
execute_command chgrp $MAEGROUP $FILELIST
execute_command chmod -R 755 $FILELIST

execute_command chmod 755 $INSTALL_DIR/pids

if [ -d $INSTALL_DIR/icudt34l ]
then
  execute_command chown $MAEUSER icudt34l
  execute_command chgrp $MAEGROUP icudt34l
  execute_command chmod -R 755 icudt34l
fi

if [ -d OpC ]
then
  execute_command chmod -R o-w OpC
fi
   
if [ -d $INSTALL_DIR/methods ]
then
  execute_command chown $MAEUSER $INSTALL_DIR/methods
fi

#
                 
# Set up the version directory owner e group  
execute_command chown $MAEUSER version/*
execute_command chgrp $MAEGROUP version/*

#
#
#  The following configuration files we require the new ones to be installed
#  so the old ones are renamed before the installconf is performed.  The
#  permissions are also set on these files as part of this process.
#
  installreqconf config/Sfinal Sfinal 700 "" "" ""
  installreqconf config/JnextPlan JnextPlan 700 "" "" ""
# cannot use installreqconf so mv directly oldest NetConf file under dir config.old
  execute_command mv $INSTALL_DIR/network/NetConf $INSTALL_DIR/config.old/NetConf 
  installconf config/NetConf network/NetConf "" "" ""
  installreqconf config/StartUp StartUp 750 "" "" ""
  installreqconf config/TWSCCLog.properties TWSCCLog.properties 444 "" "" ""
  installreqconf tws_env.sh tws_env_temp.sh 755 "" "" ""
  installreqconf tws_env.csh tws_env_temp.csh 755 "" "" ""
  installreqconf config/unixrsh methods/unixrsh 755 "" "" ""
  installreqconf config/unixssh methods/unixssh 755 "" "" ""
  installreqconf config/unixlocl methods/unixlocl 755 "" "" ""
  installreqconf config/unixrsh.wrp methods/unixrsh.wrp 755 "" "" ""
  installreqconf config/unixssh.wrp methods/unixssh.wrp 755 "" "" ""

  cp $INSTALL_DIR/tws_env_temp.sh $INSTALL_DIR/tws_env.sh
  cp $INSTALL_DIR/tws_env_temp.csh $INSTALL_DIR/tws_env.csh
     
  
# Set up the bin userscripts directory permissions
#
USERSCRIPTS="bin/at"
USERSCRIPTS="$USERSCRIPTS bin/batch"
USERSCRIPTS="$USERSCRIPTS bin/jobstdl"
USERSCRIPTS="$USERSCRIPTS bin/morestdl"
USERSCRIPTS="$USERSCRIPTS bin/rmstdlist"
USERSCRIPTS="$USERSCRIPTS bin/rep1"
USERSCRIPTS="$USERSCRIPTS bin/rep2"
USERSCRIPTS="$USERSCRIPTS bin/rep3"
USERSCRIPTS="$USERSCRIPTS bin/rep4a"
USERSCRIPTS="$USERSCRIPTS bin/rep4b"
USERSCRIPTS="$USERSCRIPTS bin/rep8"
USERSCRIPTS="$USERSCRIPTS bin/rep11"
USERSCRIPTS="$USERSCRIPTS bin/mhelp"
USERSCRIPTS="$USERSCRIPTS bin/makecal"
USERSCRIPTS="$USERSCRIPTS bin/xref"
#
for f in bin/* version/version
do
  setbinmods $f
done
 

# The jobman starter must be owned by root.
execute_command chown root $INSTALL_DIR/bin/jobman
# The starter program must be setuid root.
execute_command chown root $INSTALL_DIR/bin/starter

# Set up the man permissions
#
for file in `find man -print`
 do
    execute_command chown $MAEUSER $file
    execute_command chgrp $MAEGROUP $file
    execute_command chmod +r $file
    if [ -d $file ]
      then
      execute_command chmod +x $file
    fi
done

 
case $OS in

   DYNIX/ptx)
	#
	# On Sequent man looks for the entries under man1 and the files
	# should be packed.
	#
	for product in composer conman
	do
	  if [ -d man/$product/man1 ]
	  then
	    rm -f man/$product/man1/*
	  else
	    mkdir -p man/$product/man1
	    chown $MAEUSER  man/$product/man1
	    chgrp $MAEGROUP man/$product/man1
	  fi

	  for file in `ls man/$product/cat1/*`
	  do
	    cp $file man/$product/man1
	  done
	  chown $MAEUSER  man/$product/man1/*
	  chgrp $MAEGROUP man/$product/man1/*
	  pack -f man/$product/man1/* > /dev/null 2>&1
	done
	;;
esac

#
# Install configuration files.
#

installconf config/jobmanrc jobmanrc "" "" ""
#installconf config/localopts localopts "$THISCPU" "$MASTER"  "" - Defect 122148
installconf config/localopts localopts "$THISCPU" "$MASTER"  "" "$NM_PORT" # Defect 122148
installconf config/globalopts mozart/globalopts "$THISCPU" "$MASTER" "$COMPANY"
if [ "$INSTALL_TYPE" = "NEW" ]
then
  grep -v '^expanded[ 	][ 	]*version[ 	]*=' $INSTALL_DIR/mozart/globalopts > /tmp/e$$
  echo "expanded version            =yes" >> /tmp/e$$
  cp /tmp/e$$ $INSTALL_DIR/mozart/globalopts
  rm -f /tmp/e$$
fi

if [ ! -f $INSTALL_DIR/Security ]
then
  installconf config/Security.conf Security.conf "" "" ""
  $INSTALL_DIR/bin/makesec -l $INSTALL_DIR/Security.conf 2>&1 | tee -a $LOG_FILE
fi

exit 0
